.. thriftworker documentation master file, created by
   sphinx-quickstart on Thu Aug  9 00:44:35 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

thriftworker
==========

Listen tcp socket, parse Thrift framed protocol and distribute message between
workers using ZeroMQ.


Reference Docs
==============

.. toctree::
   :maxdepth: 1

   install
   basic_usage
   implementation
   api


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

